# -*- coding: UTF-8 -*-

from flask import Flask, request, render_template, session
from flask_babel import Babel, gettext

import settings

app = Flask(__name__)
babel = Babel(app)


@babel.localeselector
def get_locale():
    if request.args.get('lang'):
        session['lang'] = request.args.get('lang')
    return session.get('lang', 'be')


# Load default config and override config from an environment variable
app.config.update(dict(
    DEBUG=True,
    SECRET_KEY='sdfsdfsfdgdfg4fsd',
))
app.config.from_envvar('FLASKR_SETTINGS', silent=True)


def run(form_options, lang):
    tpl = """{}: {}
{}: {}
{}: {}
{}"""
    options = [form_options['checkbox1'], form_options['checkbox2'], form_options['checkbox3']]
    cleared_options = [o for o in options if o]

    if cleared_options:
        selected_options = "{}: ".format(gettext("checkbox") + ", ".join(cleared_options))

    else:
        selected_options = ""
    output_text = tpl.format(gettext("inp"), form_options['input'], gettext("selector"),
                             gettext(form_options['selector']),
                             gettext("radio"), gettext(form_options['radio']), selected_options)
    return output_text


@app.route('/', methods=['GET', 'POST'])
def ServiceDemonstrator():
    lang = get_locale()
    form_options = {}
    _input = gettext('default input').replace('\\n', '\n')
    is_post = False
    output_text = ""
    if request.method == "POST":
        is_post = True
        _input = request.form.get("inputText")
        form_options['radio'] = request.form.get("mode")
        form_options['selector'] = request.form.get("selector")
        form_options['checkbox1'] = request.form.get("checkbox1")
        form_options['checkbox2'] = request.form.get("checkbox2")
        form_options['checkbox3'] = request.form.get("checkbox3")
        form_options['input'] = request.form.get("inputText")
        output_text = run(form_options, lang)
    return render_template('index.html', is_post=is_post, form_options=form_options, output_text=output_text,
                           _input=_input, lang=lang)


if __name__ == '__main__':
    app.run(use_reloader=True, debug=True, host=settings.host, port=settings.port)
